@@ -92,6 +92,8 @@ before the docstring, you can use \n for newline, \t for tab and \s
 for space.
 
 """
+from flake8 import __version__ as flake8_version
+from pyflakes import __version__ as pep8_version
 
 __version__ = '0.6.1'
 
@@ -117,6 +119,7 @@ MAX_LINE_LENGTH = 79
 
 INDENT_REGEX = re.compile(r'([ \t]*)')
 RAISE_COMMA_REGEX = re.compile(r'raise\s+\w+\s*(,)')
+QUOTED_REGEX = re.compile(r"""([""'])(?:(?=(\\?))\2.)*?\1""")
 SELFTEST_REGEX = re.compile(r'(Okay|[EW]\d{3}):\s(.*)')
 ERRORCODE_REGEX = re.compile(r'[EW]\d{3}')
 DOCSTRING_REGEX = re.compile(r'u?r?["\']')
@@ -690,7 +693,10 @@ def python_3000_raise_comma(logical_line):
     """
     match = RAISE_COMMA_REGEX.match(logical_line)
     if match:
-        return match.start(1), "W602 deprecated form of raising exception"
+        rest = QUOTED_REGEX.sub("", logical_line)
+        # but allow three argument form of raise
+        if rest.count(",") == 1:
+            return match.start(1), "W602 deprecated form of raising exception"
 
 
 def python_3000_not_equal(logical_line):
@@ -1262,7 +1268,9 @@ def process_options(arglist=None):
     Process options passed either via arglist or via command line args.
     """
     global options, args
-    parser = OptionParser(version=__version__,
+    version = '%s (pyflakes: %s, pep8: %s)' % (flake8_version, pep8_version,
+            __version__)
+    parser = OptionParser(version=version,
                           usage="%prog [options] input ...")
     parser.add_option('--max-complexity', default=-1, action='store',
                       type='int', help="McCabe complexity treshold")
