@@ -11,7 +11,7 @@ def skip_line(line):
     return line.strip().lower().endswith('# noqa')
 
 
-_NOQA = re.compile(r'^# flake8: noqa', re.I | re.M)
+_NOQA = re.compile(r'flake8[:=]\s*noqa', re.I | re.M)
 
 
 def skip_file(path):
@@ -24,4 +24,4 @@ def skip_file(path):
         content = f.read()
     finally:
         f.close()
-    return _NOQA.match(content) is not None
+    return _NOQA.search(content) is not None
